]> sigrok.org Git - pulseview.git/blobdiff - main.cpp
Print --help/--version output to stdout (not stderr).
[pulseview.git] / main.cpp
index a7ab89fbf7422ada41d7050ac57715ce33f7f05d..e98506fcc0ea19d2d0dc2572252d3ab85748eca4 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -34,9 +34,12 @@ extern "C" {
 
 #include "config.h"
 
+// Global pointer to our QApplication
+QApplication *g_app = NULL;
+
 void usage()
 {
-       fprintf(stderr,
+       fprintf(stdout,
                "Usage:\n"
                "  %s — %s\n"
                "\n"
@@ -47,15 +50,16 @@ void usage()
 }
 
 /*
* SIGINT handler (likely recieved Ctrl-C from terminal)
  */
-void sigint(int param)
+void sigint_handler(int param)
 {
-       (void) param;
-       
-       qDebug("pv: Recieved SIGINT");
-       
-       /* TODO: Handle SIGINT */
+       (void)param;
+
+       qDebug("Received SIGINT.");
+
+       if (g_app)
+               g_app->quit();
 }
 
 int main(int argc, char *argv[])
@@ -64,9 +68,11 @@ int main(int argc, char *argv[])
        struct sr_context *sr_ctx = NULL;
 
        // Register a SIGINT handler
-       signal (SIGINT, sigint);
+       signal(SIGINT, sigint_handler);
 
        QApplication a(argc, argv);
+       // Now we have an application to populate our global pointer
+       g_app = &a;
 
        // Set some application metadata
        QApplication::setApplicationVersion(PV_VERSION_STRING);
@@ -89,7 +95,7 @@ int main(int argc, char *argv[])
                switch (c) {
                case 'V':
                        // Print version info
-                       fprintf(stderr, "%s %s\n", PV_TITLE, PV_VERSION_STRING);
+                       fprintf(stdout, "%s %s\n", PV_TITLE, PV_VERSION_STRING);
                        return 0;
 
                case 'h':
@@ -47,15 +50,16 @@ void usage()
 
 /*
- * SIGINT handler (likely recieved Ctrl-C from terminal)
+ * SIGINT handler (likely received Ctrl-C from terminal)
  */